@@ -955,12 +955,15 @@ class Api(PushEventSource):
             )
 
         if merge_definitions:
-            api["DefinitionBody"] = self._get_merged_definitions(api_id, api["DefinitionBody"], editor.swagger)
+            api["DefinitionBody"] = self._get_merged_definitions(api_id, api["DefinitionBody"], editor)
         else:
             api["DefinitionBody"] = editor.swagger
 
     def _get_merged_definitions(
-        self, api_id: str, source_definition_body: Dict[str, Any], dest_definition_body: Dict[str, Any]
+        self,
+        api_id: str,
+        source_definition_body: Dict[str, Any],
+        editor: SwaggerEditor,
     ) -> Dict[str, Any]:
         """
         Merge SAM generated swagger definition(dest_definition_body) into inline DefinitionBody(source_definition_body):
@@ -968,7 +971,7 @@ class Api(PushEventSource):
         - otherwise include key-value pairs from both definitions
         """
         merged_definition_body = source_definition_body.copy()
-        source_body_paths = merged_definition_body.get("paths", {})
+        source_body_paths = merged_definition_body.get("paths") or {}
 
         try:
             path_method_body = dict_deep_get(source_body_paths, [self.Path, self.Method]) or {}
@@ -977,7 +980,10 @@ class Api(PushEventSource):
 
         sam_expect(path_method_body, api_id, f"DefinitionBody.paths.{self.Path}.{self.Method}").to_be_a_map()
 
-        generated_path_method_body = dest_definition_body["paths"][self.Path][self.Method]
+        # Normalized version of HTTP Method. It also handle API Gateway specific methods like "ANY"
+        method = editor._normalize_method_name(self.Method)
+        dest_definition_body = editor.swagger
+        generated_path_method_body = dest_definition_body["paths"][self.Path][method]
         # this guarantees that the merged definition use SAM generated value for a conflicting key
         merged_path_method_body = {**path_method_body, **generated_path_method_body}
 
